==> zio-aws-mediapackage_3-5.17.104.9-sources.jar: zio/aws/mediapackage/model/UntagResourceRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class UntagResourceRequest(
    resourceArn: __string,
    tagKeys: Iterable[__string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest = {
    import UntagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .tagKeys(tagKeys.map { item =>
        __string.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.mediapackage.model.UntagResourceRequest.ReadOnly =
    zio.aws.mediapackage.model.UntagResourceRequest.wrap(buildAwsValue())
}
object UntagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.UntagResourceRequest =
      zio.aws.mediapackage.model.UntagResourceRequest(resourceArn, tagKeys)
    def resourceArn: __string
    def tagKeys: List[__string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTagKeys: ZIO[Any, Nothing, List[__string]] = ZIO.succeed(tagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest
  ) extends zio.aws.mediapackage.model.UntagResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.resourceArn())
    override val tagKeys: List[__string] = impl
      .tagKeys()
      .asScala
      .map { item =>
        zio.aws.mediapackage.model.primitives.__string(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest
  ): zio.aws.mediapackage.model.UntagResourceRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediapackage_3-5.17.130.7-sources.jar: zio/aws/mediapackage/model/UntagResourceRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class UntagResourceRequest(
    resourceArn: __string,
    tagKeys: Iterable[__string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest = {
    import UntagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .tagKeys(tagKeys.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.mediapackage.model.UntagResourceRequest.ReadOnly =
    zio.aws.mediapackage.model.UntagResourceRequest.wrap(buildAwsValue())
}
object UntagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.UntagResourceRequest =
      zio.aws.mediapackage.model.UntagResourceRequest(resourceArn, tagKeys)
    def resourceArn: __string
    def tagKeys: List[__string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTagKeys: ZIO[Any, Nothing, List[__string]] = ZIO.succeed(tagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest
  ) extends zio.aws.mediapackage.model.UntagResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
    override val tagKeys: List[__string] = impl
      .tagKeys()
      .asScala
      .map { item =>
        item: __string
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.UntagResourceRequest
  ): zio.aws.mediapackage.model.UntagResourceRequest.ReadOnly = new Wrapper(
    impl
  )
}
